@@ -1,6 +1,6 @@
 /* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (c) 2008  LiTL, LLC
+ * Copyright (c) 2008  litl, LLC
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -25,7 +25,7 @@
 
 #include "keep-alive.h"
 
-#include <gjs/jsapi-util.h>
+#include <gjs/gjs.h>
 
 #include <util/log.h>
 #include <util/glib.h>
@@ -148,6 +148,7 @@ trace_foreach(void *key,
     JSTracer *tracer = data;
 
     if (child->child != NULL) {
+        JS_SET_TRACING_DETAILS(tracer, NULL, "keep-alive", 0);
         JS_CallTracer(tracer, child->child, JSTRACE_OBJECT);
     }
 }
